@@ -26,7 +26,7 @@
 
 // Qt includes
 
-#include <QSvgRenderer>
+#include <QPixmap>
 
 // KDE includes
 
@@ -35,20 +35,19 @@
 
 // Local includes
 
-#include "common.h"
 #include "ui_maindialog.h"
 
 class QTreeWidgetItem;
 
 namespace KIPIPlugins
 {
-class ImagesList;
+    class ImagesList;
 }
 
 namespace KIPIAdvancedSlideshowPlugin
 {
 
-class SharedData;
+class SharedContainer;
 
 class MainDialog : public QWidget, Ui::MainDialog
 {
@@ -56,31 +55,32 @@ class MainDialog : public QWidget, Ui::MainDialog
 
 public:
 
-    MainDialog(QWidget* parent, SharedData* sharedData);
+    MainDialog(QWidget* parent, SharedContainer* sharedData);
     ~MainDialog();
 
     void readSettings();
     void saveSettings();
     bool updateUrlList();
 
+Q_SIGNALS :
+
+    void signalTotalTimeChanged(const QTime&);
+
+
 private Q_SLOTS:
 
-    void slotOpenGLToggled( void );
-    void slotEffectChanged( void );
-    void slotDelayChanged( int );
-    void slotPrintCommentsToggled( void );
-    void slotSelection( void );
-    void slotUseMillisecondsToggled( void );
+    void slotOpenGLToggled();
+    void slotEffectChanged();
+    void slotDelayChanged(int);
+    void slotPrintCommentsToggled();
+    void slotSelection();
+    void slotUseMillisecondsToggled();
     void slotThumbnail(const KUrl&, const QPixmap&);
     void slotImageListChanged();
 
-    void slotPortfolioDurationChanged ( int );
+    void slotPortfolioDurationChanged(int);
     void slotImagesFilesSelected(QTreeWidgetItem* item);
 
-Q_SIGNALS :
-
-    void totalTimeChanged( QTime );
-
 private:
 
     void setupConnections();
@@ -92,7 +92,7 @@ private:
 
 private:
 
-    SharedData*              m_sharedData;
+    SharedContainer*         m_sharedData;
     KIO::PreviewJob*         m_thumbJob;
     QTime                    m_totalTime;
     QPixmap                  m_noPreviewPixmap;
