@@ -16,10 +16,12 @@
  * GNU General Public License for more details.
  *
  * ============================================================ */
+
 #ifndef PIXMAPVIEW_H
 #define PIXMAPVIEW_H
 
-// Qt
+// Qt includes
+
 #include <QAbstractScrollArea>
 #include <QImage>
 
@@ -39,20 +41,23 @@ class PixmapView : public QAbstractScrollArea
     Q_OBJECT
 
 public:
+
     PixmapView(QWidget *parent = 0);
     ~PixmapView();
 
-    void setImage(const QString &ImagePath, const QString &tmpPath, bool cropAction);
+    void setImage(const QString& ImagePath, const QString& tmpPath, bool cropAction);
     void setZoom(int zoomFactor);
 
 Q_SIGNALS:
+
     void wheelChanged(int delta);
 
 protected:
-    void contentsWheelEvent(QWheelEvent * e);
-    void mousePressEvent(QMouseEvent * e);
-    void mouseReleaseEvent(QMouseEvent * e);
-    void mouseMoveEvent(QMouseEvent * e);
+
+    void contentsWheelEvent(QWheelEvent*);
+    void mousePressEvent(QMouseEvent*);
+    void mouseReleaseEvent(QMouseEvent*);
+    void mouseMoveEvent(QMouseEvent*);
     void paintEvent(QPaintEvent*);
     void resizeEvent(QResizeEvent*);
 
@@ -62,28 +67,31 @@ private Q_SLOTS:
     void slotPreviewProcessFinished();
 
 private:
-    QPixmap     *m_pix;
-    QImage       m_img;
 
-    int          m_w;
-    int          m_h;
-    QPoint       m_dragPos;
-
-    KProcess    *m_PreviewProc;
-
-    QString      m_previewOutput;
-    QString      m_previewFileName;
-
-    bool         m_validPreview;
-    bool         m_cropAction;
-
-    int          m_zoomFactor;
-
-    void PreviewCal(const QString &ImagePath, const QString &tmpPath);
+    void PreviewCal(const QString& ImagePath, const QString& tmpPath);
     void updateScrollBars();
     void updateView();
+
+private:
+
+    QPixmap  *m_pix;
+    QImage    m_img;
+
+    int       m_w;
+    int       m_h;
+    QPoint    m_dragPos;
+
+    KProcess *m_PreviewProc;
+
+    QString   m_previewOutput;
+    QString   m_previewFileName;
+
+    bool      m_validPreview;
+    bool      m_cropAction;
+
+    int       m_zoomFactor;
 };
 
-} // namespace
+} // namespace KIPIBatchProcessImagesPlugin
 
 #endif /* PIXMAPVIEW_H */
