@@ -71,7 +71,6 @@ extern "C"
 
 #include "dngwriter_p.h"
 #include "dngwriterhost.h"
-#include "dngwriter.h"
 
 using namespace KExiv2Iface;
 
@@ -88,7 +87,7 @@ enum DNGBayerPattern
 
 dng_date_time dngDateTime(QDateTime qDT)
 {
-    dng_date_time dngDT;    
+    dng_date_time dngDT;
     dngDT.fYear   = qDT.date().year();
     dngDT.fMonth  = qDT.date().month();
     dngDT.fDay    = qDT.date().day();
@@ -717,7 +716,7 @@ int DNGWriter::convert()
 	    dng_date_time_info dti;
 	    dti.SetDateTime(dngDateTime(meta.getImageDateTime()));
 	    exif->fDateTimeOriginal = dti;
-	    
+
 	    dti.SetDateTime(dngDateTime(meta.getDigitizationDateTime(true)));
 	    exif->fDateTimeDigitized = dti;
  
@@ -878,12 +877,18 @@ int DNGWriter::convert()
             if (meta.getExifTagLong("Exif.NikonLd3.LensIDNumber", val))                exif->fLensID.Set_ASCII((QString("%1").arg(val)).toAscii());
             if (meta.getExifTagLong("Exif.NikonLd2.FocusDistance", val))               exif->fSubjectDistance          = dng_urational((uint32)pow(10.0, val/40.0), 100);
             if (meta.getExifTagLong("Exif.NikonLd3.FocusDistance", val))               exif->fSubjectDistance          = dng_urational((uint32)pow(10.0, val/40.0), 100);
+            str = meta.getExifTagString("NikonLd1.LensIDNumber");
+            if (!str.isEmpty()) exif->fLensName.Set_ASCII(str.toAscii());
+            str = meta.getExifTagString("NikonLd2.LensIDNumber");
+            if (!str.isEmpty()) exif->fLensName.Set_ASCII(str.toAscii());
+            str = meta.getExifTagString("NikonLd3.LensIDNumber");
+            if (!str.isEmpty()) exif->fLensName.Set_ASCII(str.toAscii());
 
             // Canon Markernotes
 
             if (meta.getExifTagLong("Exif.Canon.SerialNumber", val))                   exif->fCameraSerialNumber.Set_ASCII((QString("%1").arg(val)).toAscii());
-            if (meta.getExifTagLong("Exif.CanonCs.LensType", val))                     exif->fLensID.Set_ASCII((QString("%1").arg(val)).toAscii());
-            if (meta.getExifTagLong("Exif.CanonCs.FlashActivity", val))                exif->fFlash                    = (uint32)val;
+            //if (meta.getExifTagLong("Exif.CanonCs.LensType", val))                     exif->fLensID.Set_ASCII((QString("%1").arg(val)).toAscii());
+            //if (meta.getExifTagLong("Exif.CanonCs.FlashActivity", val))                exif->fFlash                    = (uint32)val;
             //if (meta.getExifTagLong("Exif.CanonFi.FileNumber", val))                   exif->fImageNumber              = (uint32)val;
             //if (meta.getExifTagLong("Exif.CanonCs.MaxAperture", val))                  exif->fMaxApertureValue         = dng_urational(val, 100000);
             if (meta.getExifTagLong("Exif.CanonCs.ExposureProgram", val))
@@ -935,6 +940,28 @@ int DNGWriter::convert()
             if (meta.getExifTagRational("Exif.CanonCs.Lens", num, den, 0))             exif->fLensInfo[1]              = dng_urational(num, canonLensUnits);
             if (meta.getExifTagRational("Exif.CanonCs.Lens", num, den, 1))             exif->fLensInfo[0]              = dng_urational(num, canonLensUnits);
             if (meta.getExifTagRational("Exif.Canon.FocalLength", num, den, 1))        exif->fFocalLength              = dng_urational(num, canonLensUnits);
+            long canonLensType = 65535;
+            if (meta.getExifTagLong("Exif.CanonCs.LensType", canonLensType))           exif->fLensID.Set_ASCII((QString("%1").arg(canonLensType)).toAscii());
+            str = meta.getExifTagString("Exif.Canon.LensModel");
+            if (!str.isEmpty())
+                exif->fLensName.Set_ASCII(str.toAscii());
+            else if (canonLensType != 65535)
+            {
+                str = meta.getExifTagString("Exif.CanonCs.LensType");
+                if (!str.isEmpty()) exif->fLensName.Set_ASCII(str.toAscii());
+            }
+            else if ((exif->fLensInfo[0].n > 0) && (exif->fLensInfo[1].n > 0))
+            {
+                double focalLenght = (double)exif->fLensInfo[0].n / (double)exif->fLensInfo[0].d;
+                QString lensName = QString("%1").arg(focalLenght, 0, 'f', 1);
+                if (exif->fLensInfo[0].n != exif->fLensInfo[1].n)
+                {
+                    focalLenght = (double)exif->fLensInfo[1].n / (double)exif->fLensInfo[1].d;
+                    lensName.append(QString("-%1").arg(focalLenght, 0, 'f', 1));
+                }
+                lensName.append(" mm");
+                exif->fLensName.Set_ASCII(lensName.toAscii());
+            }
 
             str = meta.getExifTagString("Exif.Canon.OwnerName");
             if (!str.isEmpty()) exif->fOwnerName.Set_ASCII(str.toAscii());
@@ -972,8 +999,52 @@ int DNGWriter::convert()
                 AutoPtr<dng_memory_block> block(host.Allocate(mkrnts.size()));
                 stream.SetReadPosition(0);
                 stream.Get(block->Buffer(), mkrnts.size());
-                negative->SetMakerNote(block);
-                negative->SetMakerNoteSafety(true);
+
+                if (identifyMake.make != "Canon")
+                {
+                    negative->SetMakerNote(block);
+                    negative->SetMakerNoteSafety(true);
+                }
+
+                long mknOffset       = 0;
+                QString mknByteOrder = meta.getExifTagString("Exif.MakerNote.ByteOrder");
+
+                if ((meta.getExifTagLong("Exif.MakerNote.Offset", mknOffset)) && !mknByteOrder.isEmpty())
+                {
+                    dng_memory_stream streamPriv(memalloc);
+                    QByteArray identPriv;
+
+                    identPriv.append(QString("Adobe").toAscii());
+                    identPriv.append((char)0x00);
+                    identPriv.append(QString("MakN").toAscii());
+
+                    // next four byte are makernote size
+                    int mknSize = mkrnts.size();
+                    int size    = mknSize + 6;
+                    identPriv.append((char)((size >> 24) & 0xFF));
+                    identPriv.append((char)((size >> 16) & 0xFF));
+                    identPriv.append((char)((size >> 8 ) & 0xFF));
+                    identPriv.append((char)((size      ) & 0xFF));
+
+                    kDebug() << mknSize << " " << mknOffset << " " << mknByteOrder;
+
+                    // byte order
+                    identPriv.append(mknByteOrder.toAscii());
+
+                    // next four byte are original offset
+                    identPriv.append((char)((mknOffset >> 24) & 0xFF));
+                    identPriv.append((char)((mknOffset >> 16) & 0xFF));
+                    identPriv.append((char)((mknOffset >> 8 ) & 0xFF));
+                    identPriv.append((char)((mknOffset      ) & 0xFF));
+
+
+                    streamPriv.Put(identPriv, identPriv.size());
+                    streamPriv.Put(mkrnts.data(), mkrnts.size());
+                    AutoPtr<dng_memory_block> blockPriv(host.Allocate(identPriv.size() + mkrnts.size()));
+                    streamPriv.SetReadPosition(0);
+                    streamPriv.Get(blockPriv->Buffer(), identPriv.size() + mkrnts.size());
+                    negative->SetPrivateData(blockPriv);
+                }
             }
         }
 
@@ -1192,14 +1263,15 @@ int DNGWriter::convert()
     return dng_error_none;
 }
 
-bool DNGWriter::fujiRotate(QByteArray &rawData, KDcrawIface::DcrawInfoContainer &identify)
+bool DNGWriter::fujiRotate(QByteArray& rawData, KDcrawIface::DcrawInfoContainer& identify)
 {
     QByteArray tmpData(rawData);
     int height = identify.outputSize.height();
     int width  = identify.outputSize.width();
 
-    unsigned short *tmp = (unsigned short *)tmpData.data();
-    unsigned short *output = (unsigned short *)rawData.data();
+    unsigned short* tmp    = (unsigned short*)tmpData.data();
+    unsigned short* output = (unsigned short*)rawData.data();
+
     for (int row=0; row < height; row++)
     {
         for (int col=0; col < width; col++)
