@@ -6,7 +6,7 @@
  * Date        : 2008-09-24
  * Description : Raw file list view used into batch DNG converter.
  *
- * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -44,13 +44,21 @@ class CListViewItem : public QTreeWidgetItem
 
 public:
 
-    CListViewItem(QTreeWidget *view, const QPixmap& pixmap, const KUrl& url, const QString& fileName)
+    enum State
+    {
+        Waiting,
+        Success,
+        Failed
+    };
+
+    CListViewItem(QTreeWidget* view, const QPixmap& pixmap, const KUrl& url, const QString& fileName)
         : QTreeWidgetItem(view)
     {
          setThumbnail(pixmap);
          setUrl(url);
          setDestFileName(fileName);
          setEnabled(true);
+         setState(Waiting);
     }
 
     ~CListViewItem(){}
@@ -71,6 +79,16 @@ public:
         setIcon(1, icon);
     }
 
+    void setState(State state)
+    {
+        m_state = state;
+    }
+
+    State state() const
+    {
+        return m_state;
+    }
+
     void setUrl(const KUrl& url) 
     {
         m_url = url;
@@ -132,6 +150,7 @@ private:
     QString m_identity;
 
     KUrl    m_url;
+    State   m_state;
 };
 
 } // namespace KIPIDNGConverterPlugin
