@@ -35,7 +35,7 @@
 
 // KDE includes
 
-#include <KDebug>
+#include <kdebug.h>
 #include <KConfig>
 #include <KLocale>
 #include <KMenu>
@@ -55,10 +55,6 @@
 #include <libkdcraw/version.h>
 #include <libkdcraw/kdcraw.h>
 
-#if KDCRAW_VERSION < 0x000400
-#include <libkdcraw/dcrawbinary.h>
-#endif
-
 // LibKIPI includes
 
 #include <libkipi/interface.h>
@@ -90,8 +86,8 @@ FbWindow::FbWindow(KIPI::Interface* interface, const QString &tmpFolder,
 
     setMainWidget(m_widget);
     setWindowIcon(KIcon("facebook"));
-    setButtons(Help|User1|Cancel);
-    setDefaultButton(Cancel);
+    setButtons(Help|User1|Close);
+    setDefaultButton(Close);
     setModal(false);
 
     if (import)
@@ -204,7 +200,6 @@ FbWindow::FbWindow(KIPI::Interface* interface, const QString &tmpFolder,
 
 FbWindow::~FbWindow()
 {
-    delete m_talker;
     delete m_about;
 }
 
@@ -215,10 +210,9 @@ void FbWindow::slotHelp()
 
 void FbWindow::slotButtonClicked(int button)
 {
-    kDebug() << "TODO: FbWindow::slotButtonClicked";
     switch (button)
     {
-        case Cancel:
+        case Close:
             if (m_widget->progressBar()->isHidden())
             {
                 writeSettings();
@@ -599,8 +593,8 @@ void FbWindow::setProfileAID(long long userID)
 {
     // store AID of Profile Photos album
     // http://wiki.developers.facebook.com/index.php/Profile_archive_album
-    m_profileAID = (userID << 32) +
-                   (-3 & 0xFFFFFFFF);
+    m_profileAID = QString::number((userID << 32) 
+                                   + (-3 & 0xFFFFFFFF));
 }
 
 QString FbWindow::getImageCaption(const KExiv2Iface::KExiv2& ev)
@@ -705,11 +699,7 @@ void FbWindow::uploadNextPhoto()
     m_widget->progressBar()->setValue(m_imagesCount);
 
     // check if we have to RAW file -> use preview image then
-#if KDCRAW_VERSION < 0x000400
-    QString rawFilesExt(KDcrawIface::DcrawBinary::instance()->rawFiles());
-#else
     QString rawFilesExt(KDcrawIface::KDcraw::rawFiles());
-#endif
     QFileInfo fileInfo(imgPath);
     QString caption;
     bool isRAW = rawFilesExt.toUpper().contains(fileInfo.suffix().toUpper());
